==> cosmos-sdd-runtime-sdk-COSMOS-1.1.0-200908120317.zip: org/eclipse/cosmos/me/sdd/profile/cim/handler/InstalledProductHandler.java <==
/***********************************************************************
 * Copyright (c) 2009 SAS Institute, Inc. and others
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     SAS Institute - initial API and implementation
 ***********************************************************************/
package org.eclipse.cosmos.me.sdd.profile.cim.handler;

import java.text.MessageFormat;

import javax.xml.bind.JAXBElement;
import javax.xml.namespace.QName;

import org.eclipse.cosmos.me.sdd.cr.IResourceHandler;
import org.eclipse.cosmos.me.sdd.profile.cim.InstalledProductType;
import org.eclipse.cosmos.me.sdd.schema.CapacityConstraintType;
import org.eclipse.cosmos.me.sdd.schema.ConditionalPropertyConstraintType;
import org.eclipse.cosmos.me.sdd.schema.ConsumptionConstraintType;
import org.eclipse.cosmos.me.sdd.schema.PropertyConstraintType;
import org.eclipse.cosmos.me.sdd.schema.RequirementResourceConstraintType;
import org.eclipse.cosmos.me.sdd.schema.ResourceType;
import org.eclipse.cosmos.me.sdd.schema.VersionConstraintType;
import org.eclipse.cosmos.me.sdd.schema.ext.SDDContext;

public class InstalledProductHandler extends InstalledProductType implements IResourceHandler {
	
	public boolean evaluate(SDDContext ctxt, ResourceType rsrc,
			CapacityConstraintType constraint) {
		return false;
	}

	public boolean evaluate(SDDContext ctxt, ResourceType rsrc,
			ConsumptionConstraintType constraint) {
		return false;
	}

	public boolean evaluate(SDDContext ctxt, ResourceType rsrc,
			PropertyConstraintType constraint) {
		return false;
	}

	public boolean evaluate(SDDContext ctxt, ResourceType rsrc,
			ConditionalPropertyConstraintType constraint) {
		return false;
	}

	public boolean evaluate(SDDContext ctxt, ResourceType rsrc,
			VersionConstraintType constraint) {
		return false;
	}
	
	public boolean evaluate(SDDContext ctxt, ResourceType rsrc,
			RequirementResourceConstraintType constraint) {
		
		String product = null;
		String version = null;
		String vendor = null;
		
		for (Object o : constraint.getResourceConstraintGroup()) {
			if (o instanceof JAXBElement) {
				Object value = ((JAXBElement<?>)o).getValue();
		
				String constraintValue = null;
				QName name = null;
				
				if (value instanceof PropertyConstraintType) {
					if (value instanceof ConditionalPropertyConstraintType) {
						ConditionalPropertyConstraintType cc = (ConditionalPropertyConstraintType) value;
						name = cc.getPropertyName();
						constraintValue = cc.getValue();
					} else if (value instanceof PropertyConstraintType) {
						PropertyConstraintType cc = (PropertyConstraintType) value;
						name = cc.getPropertyName();
						constraintValue = cc.getValue();
					}
				}
				else if (value instanceof VersionConstraintType) {
					// not handling versions for installed product yet.
				}
				
				if (IP_PVENDOR.equals(name))
					vendor = constraintValue;
				else if (IP_PNAME.equals(name))
					product = constraintValue;
				else if (IP_PVERSION.equals(name))
					version = constraintValue;
			}	
		}
		
		if (System.getProperty(OS_NAME).contains(Windows)) {
			for(int i=0; i<winPatterns.length; i++) {
				String s = winFind(MessageFormat.format(winPatterns[i], vendor, product, version));
				if(s != null) {
					return true;
				}
			}
		}
		else {
			for(int i=0; i<unixPatterns.length; i++) {
				String s = unixFind(MessageFormat.format(unixPatterns[i], product, version, vendor));
				if(s != null) {
					return true;
				}
			}
		}
		
		return false;
	}
	
	public Object getPropertyValue(SDDContext ctxt, ResourceType rsrc, QName qname) {
		return null;
	}

	public Object getVersionValue(SDDContext ctxt, ResourceType rsrc) {
		return null;
	}
}

==> cosmos-sdd-runtime-sdk-COSMOS-1.2.0-201004031715.zip: org/eclipse/cosmos/me/sdd/profile/cim/handler/InstalledProductHandler.java <==
/***********************************************************************
 * Copyright (c) 2009 SAS Institute, Inc. and others
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     SAS Institute - initial API and implementation
 ***********************************************************************/
package org.eclipse.cosmos.me.sdd.profile.cim.handler;

import java.text.MessageFormat;

import javax.xml.bind.JAXBElement;
import javax.xml.namespace.QName;

import org.eclipse.cosmos.me.sdd.cr.IResourceHandler;
import org.eclipse.cosmos.me.sdd.profile.cim.InstalledProductType;
import org.eclipse.cosmos.me.sdd.schema.CapacityConstraintType;
import org.eclipse.cosmos.me.sdd.schema.ConditionalPropertyConstraintType;
import org.eclipse.cosmos.me.sdd.schema.ConsumptionConstraintType;
import org.eclipse.cosmos.me.sdd.schema.PropertyConstraintType;
import org.eclipse.cosmos.me.sdd.schema.RequirementResourceConstraintType;
import org.eclipse.cosmos.me.sdd.schema.ResourceType;
import org.eclipse.cosmos.me.sdd.schema.VersionConstraintType;
import org.eclipse.cosmos.me.sdd.schema.ext.SDDContext;

public class InstalledProductHandler extends InstalledProductType implements IResourceHandler {
	
	public boolean evaluate(SDDContext ctxt, ResourceType rsrc,
			CapacityConstraintType constraint) {
		return false;
	}

	public boolean evaluate(SDDContext ctxt, ResourceType rsrc,
			ConsumptionConstraintType constraint) {
		return false;
	}

	public boolean evaluate(SDDContext ctxt, ResourceType rsrc,
			PropertyConstraintType constraint) {
		return false;
	}

	public boolean evaluate(SDDContext ctxt, ResourceType rsrc,
			ConditionalPropertyConstraintType constraint) {
		return false;
	}

	public boolean evaluate(SDDContext ctxt, ResourceType rsrc,
			VersionConstraintType constraint) {
		return false;
	}
	
	public boolean evaluate(SDDContext ctxt, ResourceType rsrc,
			RequirementResourceConstraintType constraint) {
		
		String product = null;
		String version = null;
		String vendor = null;
		
		for (Object o : constraint.getResourceConstraintGroup()) {
			if (o instanceof JAXBElement<?>) {
				Object value = ((JAXBElement<?>)o).getValue();
		
				String constraintValue = null;
				QName name = null;
				
				if (value instanceof PropertyConstraintType) {
					if (value instanceof ConditionalPropertyConstraintType) {
						ConditionalPropertyConstraintType cc = (ConditionalPropertyConstraintType) value;
						name = cc.getPropertyName();
						constraintValue = cc.getValue();
					} else if (value instanceof PropertyConstraintType) {
						PropertyConstraintType cc = (PropertyConstraintType) value;
						name = cc.getPropertyName();
						constraintValue = cc.getValue();
					}
				}
				else if (value instanceof VersionConstraintType) {
					// not handling versions for installed product yet.
				}
				
				if (IP_PVENDOR.equals(name))
					vendor = constraintValue;
				else if (IP_PNAME.equals(name))
					product = constraintValue;
				else if (IP_PVERSION.equals(name))
					version = constraintValue;
			}	
		}
		
		if (System.getProperty(OS_NAME).contains(Windows)) {
			for(int i=0; i<winPatterns.length; i++) {
				String s = winFind(MessageFormat.format(winPatterns[i], vendor, product, version));
				if(s != null) {
					return true;
				}
			}
		}
		else {
			for(int i=0; i<unixPatterns.length; i++) {
				String s = unixFind(MessageFormat.format(unixPatterns[i], product, version, vendor));
				if(s != null) {
					return true;
				}
			}
		}
		
		return false;
	}
	
	public Object getPropertyValue(SDDContext ctxt, ResourceType rsrc, QName qname) {
		return null;
	}

	public Object getVersionValue(SDDContext ctxt, ResourceType rsrc) {
		return null;
	}
}
